# Barfi

**Block and Link based graphical programming environment for performing simulations in Python.**

It provides a Streamlit component for a graphical programming environment to perform simulations.

